﻿using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

using MindFusion.Common.WinForms;
using MindFusion.Mapping;
using MindFusion.Mapping.WinForms;


namespace Countries
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			// find the folder containing admin. division maps
			var countryFolder = FindFolder("countries_level_1");
			if (countryFolder != null)
			{
				// get all map files
				var dir = new DirectoryInfo(countryFolder);
				mapFiles = dir.GetFiles("*.shp");
				foreach (var map in mapFiles)
				{
					// add map name to listbox
					var name = Path.GetFileNameWithoutExtension(map.Name);
					lbCountries.Items.Add(name);
				}

				// select first country
				lbCountries.SelectedIndex = 0;
			}

			// show zoom widget
			var zoomControl = new ZoomControl();
			zoomControl.Height = 300;
			zoomControl.Width = 55;
			zoomControl.Location = new System.Drawing.Point(
				mapView.Bounds.X + 20, mapView.Bounds.Y + 40);
			zoomControl.Target = mapView;
			zoomControl.ScrollStep = -20;
			Controls.Add(zoomControl);
			zoomControl.BringToFront();

			mapView.Layers[0].FillColors = new Color[] { Color.Lavender, Color.Linen, Color.PapayaWhip  };
			mapView.BaseMap.AssignColors();

			mapView.Focus();
		}

		private void miFileLoadMap_Click(object sender, EventArgs e)
		{
			var openDialog = new OpenFileDialog
			{
				Filter = "Shapefile map|*.shp",
				Title = "Open map"
			};

			if (openDialog.ShowDialog() == DialogResult.OK)
			{
				mapView.BaseMap = new Map();
				mapView.BaseMap.LoadFromFile(openDialog.FileName);
				mapView.Invalidate();
			}
		}

		private void miFileExit_Click(object sender, EventArgs e)
		{
			Close();
		}

		private string FindFolder(string folderName)
		{
			string testDir = @"..\Maps\";
			for (int i = 0; i < 10; i++)
			{
				if (Directory.Exists(testDir))
					break;
				testDir = @"..\" + testDir;
			}

			var testFolder = testDir + folderName;
			if (Directory.Exists(testFolder))
				return testFolder;

			return "";
		}

		private void lbCountries_SelectedIndexChanged(object sender, EventArgs e)
		{
			int index = lbCountries.SelectedIndex;
			if (mapFiles != null && index >= 0 && index < mapFiles.Length)
			{
				// show the country name
				lblCountryName.Text = lbCountries.SelectedItem.ToString();

				// load the map, get region names from column NAME_1
				mapView.BaseMap = Map.FromFile(mapFiles[index].FullName, true, "NAME_1");

				// assign map colors so that adjacent regions are painted in different color
				
				mapView.BaseMap.AssignColors();

				mapView.Invalidate();
			}
		}

		FileInfo[] mapFiles;
	}
}